@@ -20,6 +20,6 @@ from pyutilib.workflow.file import *
 from pyutilib.workflow.executable import *
 from pyutilib.workflow.tasks import *
 from pyutilib.workflow.driver import *
-from _functor import *
+from pyutilib.workflow.functor import *
 
 pyutilib.component.core.PluginGlobals.pop_env()
